unit MainForm;

interface

uses
  System.SysUtils, System.Types, System.UITypes, System.Classes, System.Variants,
  FMX.Types, FMX.Controls, FMX.Forms, FMX.Graphics, FMX.Dialogs, Data.DB,
  DBAccess, MyAccess, Data.Bind.EngExt, gtClasses, Fmx.Bind.DBEngExt,
  System.Rtti, System.Bindings.Outputs, Data.Bind.Components, Data.Bind.Grid,
  Data.Bind.DBScope, MemDS, FMX.TMSBaseControl, FMX.TMSGridCell,
  FMX.TMSGridOptions, FMX.TMSGridData, FMX.TMSCustomGrid, FMX.TMSLiveGrid,
  FMX.TMSLiveGridDataBinding, Fmx.Bind.Editors, FMX.Layouts,
  FMX.Controls.Presentation, FMX.StdCtrls, FMX.Objects;

type
  TfrmMain = class(TForm)
    CnnToShopping: TMyConnection;
    QItem: TMyQuery;
    DsItem: TMyDataSource;
    BindSourceDB1: TBindSourceDB;
    BindingsList1: TBindingsList;
    ScaledLayout1: TScaledLayout;
    GridPanelLayout1: TGridPanelLayout;
    grdItem: TTMSFMXLiveGrid;
    Buttons: TGridPanelLayout;
    LinkGridToDataSourceBindSourceDB12: TLinkGridToDataSource;
    Rectangle1: TRectangle;
    Label1: TLabel;
    procedure grdItemGetCellData(Sender: TObject; ACol, ARow: Integer;
      var CellString: string);
    procedure grdItemGetCellLayout(Sender: TObject; ACol, ARow: Integer;
      ALayout: TTMSFMXGridCellLayout; ACellState: TCellState);
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure grdItemColumnCalc(Sender: TObject; ACol, FromRow, ToRow: Integer;
      var Res: Double);
    procedure Rectangle1Click(Sender: TObject);
  private
    { Private declarations }
    procedure FooterUpdate;
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;
  Tot1: String;
  SQLString: String;
Const
  StoreCurrency = '';
  RedColor = $007373FF;
  CloseColor = $00AFFFFF;
  DisableColor = $00EEEEEE;
  DeleteColor = $00A7A7FF;
  SearchGreen = $00BEEB91;
implementation
{$R *.fmx}

procedure TfrmMain.FooterUpdate;
begin
  Tot1 := FormatFloat('0', QItem.RecordCount);
  grdItem.HideColumns(17, 16);
  grdItem.ColumnCalculation[1] := TColumnCalculation.ccCustom;
  grdItem.ColumnCalculation[8] := TColumnCalculation.ccCustom;
  grdItem.ColumnCalculation[9] := TColumnCalculation.ccCustom;
  grdItem.ColumnCalculation[10] := TColumnCalculation.ccCustom;
  grdItem.ColumnCalculation[11] := TColumnCalculation.ccCustom;
  grdItem.UpdateCalculations;
end;

procedure TfrmMain.FormCreate(Sender: TObject);
begin
  Width := Round(Screen.Width);
  Height := Round(Screen.Height);
end;

procedure TfrmMain.FormShow(Sender: TObject);
begin
  CnnToShopping.Connected := True;
  QItem.Connection := CnnToShopping;
  SQLString := 'select *, (100 * ITEM_CP)/ (ITEM_VATRATE + 100) AS CPEXVAT, '+
                 '(100 * ITEM_PRICE)/ (ITEM_VATRATE + 100) AS SPEXVAT, '+
                 '(100 * ITEM_CP)/ (ITEM_VATRATE + 100) * ITEM_STOCK AS TCPEXVAT, '+
                 'ITEM_CP * ITEM_STOCK AS TCPINVAT, '+
                 '(100 * ITEM_PRICE)/ (ITEM_VATRATE + 100) * ITEM_STOCK AS TSPEXVAT, '+
                 'ITEM_PRICE * ITEM_STOCK AS TSPINVAT, '+
                 '(ITEM_PRICE - ITEM_CP) AS PROFITD, '+
                 '((ITEM_PRICE - ITEM_CP) * 100 / ITEM_PRICE) AS PROFITPER '+
                 'from CS_ITEMS ORDER BY ITEM_NAME ASC';
  with QItem do
  begin
    Close;
    SQL.Clear;
    SQL.Add(SQLString);
    Open;
  end;
  FooterUpdate;
end;

procedure TfrmMain.grdItemColumnCalc(Sender: TObject; ACol, FromRow,
  ToRow: Integer; var Res: Double);
begin
  if ACol = 1 then
  begin
    if Tot1 <> '' then
       Res := StrToInt(Tot1);
  end;
end;

procedure TfrmMain.grdItemGetCellData(Sender: TObject; ACol, ARow: Integer;
  var CellString: string);
begin
  if ARow = 0 then
    exit;
  if CellString = '' then
    exit;
  if (ACol = 7) or (ACol = 14) or (ACol = 15)  then
    CellString := FormatFloat('0.000', StrToFloat(CellString))
  else if (ACol = 2) then
    CellString := FormatFloat('0.00', StrToFloat(CellString))
  else if (ACol = 3) or (ACol = 4) or (ACol = 5) or (ACol = 6) or (ACol = 8) or (ACol = 9) or (ACol = 10) or (ACol = 11) then
    CellString := FormatFloat(StoreCurrency + '0.000', StrToFloat(CellString))
  else if (ACol = 12) then
    CellString := FormatFloat('0.00 %', StrToFloat(CellString))
  else if (ACol = 13) then
    CellString := FormatFloat(StoreCurrency + '0.00 ', StrToFloat(CellString));
end;

procedure TfrmMain.grdItemGetCellLayout(Sender: TObject; ACol, ARow: Integer;
  ALayout: TTMSFMXGridCellLayout; ACellState: TCellState);
var
  aRowColor: TBrush;
  aVal: String;
begin
  aVal := FormatFloat('0.000', 0);
  aRowColor := TBrush.Create(TBrushKind.Solid, TAlphaColors.Alpha);
  try
    ALayout.FontFill.Color := TAlphaColorRec.Black;
    if (ARow < grdItem.FixedRows) or (ARow > QItem.RecordCount)  then
      aRowColor.Color := SearchGreen
    else begin
      aVal := FormatFloat('0.000',grdItem.AllFloats[0, ARow]);
      if (ACellState = TCellState.csFocused) or  (ACellState = TCellState.csSelected) then
          aRowColor.Color := CloseColor
      else
        aRowColor.Color := TAlphaColorRec.White;
    end;
    ALayout.Fill := aRowColor;
    ALayout.Font.Family := 'Roboto';
    ALayout.Font.Size := 16;
    ALayout.Font.Style := [];
    if StrToFloat(aVal) > 0.000  then
      ALayout.FontFill.Color := TAlphaColorRec.Blue
    else if StrToFloat(aVal) < 0.000  then
      ALayout.FontFill.Color := TAlphaColorRec.Red
    else
      ALayout.FontFill.Color := TAlphaColorRec.Black;
  finally
    aRowColor.Free;
  end;
end;

procedure TfrmMain.Rectangle1Click(Sender: TObject);
begin
//  Rectangle1.Fill.Color := RedColor;
  try
    SQLString := 'select *, (100 * ITEM_CP)/ (ITEM_VATRATE + 100) AS CPEXVAT, '+
                   '(100 * ITEM_PRICE)/ (ITEM_VATRATE + 100) AS SPEXVAT, '+
                   '(100 * ITEM_CP)/ (ITEM_VATRATE + 100) * ITEM_STOCK AS TCPEXVAT, '+
                   'ITEM_CP * ITEM_STOCK AS TCPINVAT, '+
                   '(100 * ITEM_PRICE)/ (ITEM_VATRATE + 100) * ITEM_STOCK AS TSPEXVAT, '+
                   'ITEM_PRICE * ITEM_STOCK AS TSPINVAT, '+
                   '(ITEM_PRICE - ITEM_CP) AS PROFITD, '+
                   '((ITEM_PRICE - ITEM_CP) * 100 / ITEM_PRICE) AS PROFITPER '+
                   'from CS_ITEMS ORDER BY ITEM_NAME ASC';
    grdItem.BeginUpdate;
    with QItem do
    begin
      Close;
      SQL.Clear;
      SQL.Add(SQLString);
      Open;
    end;
    FooterUpdate;
    grdItem.EndUpdate;
  finally
  //  Rectangle1.Fill.Color := CloseColor;
  end;
end;

end.
